@@ -380,8 +380,8 @@ class Type(type):
             else: output.append(x)
         return output
 
-    @list_type_args
     def __new__(cls, *_T, name=None, shape=tuple(), inv=False, ext=False, itypes=None):
+        if len(_T) == 1 and not isatype(_T): _T = _T[0]
         if len(_T) > 0 and not isatype(_T): raise SyntaxError("Wrong parameter type. ")
         _T = Type.extractType(_T)
         baseT = []
@@ -530,19 +530,17 @@ class Type(type):
                     else: itypes = self.itemtypes
                     for dt in Type.extractType(itypes):
                         if isinstance(dt, Type):
-                            x = arg
-                            while True:
-                                x = x[0]
-                                try:
-                                    if len(x) == 1: break
-                                except TypeError: break
+                            x = arg[(0,) * len(arg.shape)]
                             return isoftype(x, dt)
                         if isdtype(dt): dt = dname(dt)
                         if isatype(dt): dt = _rawname(dt)
                         if dname(arg.dtype) == dt: return true
                     return false
                 elif isatype(self.itemtypes):
-                    for x in arg:
+                    import random
+                    for _ in range(5):
+                        try: x = random.choice(arg)
+                        except: x = arg.pop()
                         if not isoftype(x, self.itemtypes): return false
                 else: raise TypeHintError("Invalid item types after @, please use iterable or types.")
             return true
